Summary: C++ library for HPC, parallel processing, networking, DB, memory, etc
Name: UpTools
Version: 8.6.3
Release: 2%{dist}
License: BSD with attribution 
Group: Development/Libraries
Source: http://www.palermo.edu/ingenieria/%{name}-%{version}.tar.gz
URL: http://www.palermo.edu/ingenieria/uptools_ingles.html
BuildRequires: mysql-devel
BuildRequires: postgresql-devel
BuildRequires: openssl-devel

%description
UpTools is an open source C++ development library that contains powerful
classes to facilitate and accelerate modern application development. The
following aspects are covered by the library: High performance computing
(HPC), Load distribution and parallel processing, Multi-threading, Time
and timers, Memory management, Text and strings, Database access,
Networking, and others.

UpTools is developed and maintained by the Engineering School of the
Universidad de Palermo, and originated in its Electronics and Communications
Department projects.

%package devel
Summary: Header files and examples for UpTools C++ library
Group: Development/Libraries
Requires: %{name}%{?_isa} = %{version}-%{release}
Requires: libstdc++-devel%{?_isa}
Requires: openssl-devel%{?_isa}
Requires: mysql-devel%{?_isa}
Requires: postgresql-devel%{?_isa}
 
%description devel
UpTools is an open source C++ development library that contains powerful
classes to facilitate and accelerate modern application development. The
following aspects are covered by the library: High performance computing
(HPC), Load distribution and parallel processing, Multi-threading, Time
and timers, Memory management, Text and strings, Database access,
Networking, and others.

UpTools is developed and maintained by the Engineering School of the
Universidad de Palermo, and originated in its Electronics and Communications
Department projects.

This package include headers to build apps using UpTools and example code.


%prep
%setup -q  
#Remove glibc workaround test
cp -p configure configure.backup
sed -i   -e '16071,16089d' configure
touch -r configure.backup configure

%build


# We use unordered_map and unordered_set instead the hash_map and hash_set
%configure --disable-static LDFLAGS="-L%{_libdir}/mysql"

make %{?_smp_mflags} 

%install
make install DESTDIR=%{buildroot} INSTALL="install -p"

rm -rf  %{buildroot}/%{_docdir}/%{name}

# We don't want .la libtool archive
rm -f %{buildroot}%{_libdir}/libUpTools.la
%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%defattr(-,root,root,-)
%{_libdir}/libUpTools.so.*
%doc README LICENSE doc/MULTITHREADING.INTRO doc/INTRO

%files devel
%defattr(-,root,root,-)
%dir %{_includedir}/UpTools
%{_includedir}/UpTools/*
%{_libdir}/libUpTools.so
%doc LICENSE doc/README.FEDORA doc/examples

%changelog
* Tue Jul 16 2013 Sergio Belkin <sebelk@fedoraproject.org> - 8.6.3-2
- Minor interface improvements for speed, inheritance and functionality

* Wed Feb 13 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 8.6.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Wed Jul 18 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 8.6.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Thu Mar 15 2012 Sergio Belkin <sebelk@fedoraproject.org> - 8.6.2-1
- Minor fixes in UpTimeVal
- Added example code testUpRoute

* Tue Feb 28 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 8.6.1-3
- Rebuilt for c++ ABI breakage

* Thu Jan 12 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 8.6.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Thu Sep 19 2011 Sergio Belkin <sebelk@fedoraproject.org> - 8.6.1-1
- A new class UpRoute is added to make very fast route table lookups both in
    IPv4 and IPv6
- UpAddress and UpSockAddr IPv6 handling is optimized for 64
    bits processors
- License tag fixed, now is "BSD with attribution"
- Replaced inet_net_pton in AC_SEARCH_LIBS for resolv library
  because there was a dependency issue creating RPM in epel5
- Moved "-no-install" from configure.ac to Makefile.am
- Fixed conditional for postgresql

* Thu May 16 2011 Sergio Belkin <sebelk@fedoraproject.org> - 8.5.5-3
- UpTimerManager extension to report on pending timers of each type, and new
  flexibility in timer setup parameters. Method now() of UpTimerManager is
  fortified.
- One of the operators for UpSmartLinkPtr's is removed to help g++ resolve
  compilation ambiguity.
- Disable silent rules and gcc warning flags of configure.ac
- Get rid of ugly macro AX_EXT_HAVE_LIB
- Dropped --as-needed and -O3 flags in order to be more generic and simple build
- Loop to search mysqlclient with proper LDFLAGS
- Removed test for old glibc and prevent libdir harcoding
- Remove -no-install LDFLAG
- Not it uses 
- Fixed license, it was tagged wrongly as "BSD with advertisement", has been
  replaced by the recently accepted "BSD with attribution"
- Polished the test for old glibc

* Fri Mar 25 2011 Dan Horák <dan@danny.cz> - 8.5.4-13
- fix build on 64-bit platforms (don't fiddle with libdir in configure)
- fix build on s390 where size_t is unsigned long


* Wed Mar 23 2011 Dan Horák <dan@danny.cz> - 8.5.4-12
- rebuilt for mysql 5.5.10 (soname bump in libmysqlclient)


* Tue Mar 01 2011 Sergio Belkin <sebelk@fedoraproject.org> - 8.5.4-11
- Fixed typo in previous changelog entry
- Fixed release number in previous changelog entry

* Mon Feb 28 2011 Sergio Belkin <sebelk@fedoraproject.org> - 8.5.4-10
- Used %%{_libdir} macro instead of the conditional statement ifarch
  and hardcoded paths

* Sat Feb 26 2011 Sergio Belkin <sbelki@palermo.edu> - 8.5.4-9
- Set LDFLAGS for mysqclient, in order to prevent misleading 
  messages from macro ax_ext_have_lib.m4
- Added libstdc++-devel
- Added --disable-silent-rules to configure script 
- Removed %%check section it is not needed
- Minor aesthetic changes to changelog

* Fri Feb 25 2011 Sergio Belkin <sbelki@palermo.edu> - 8.5.4-8
- Removed redundant "/usr/bin" before iconv
- Preserved timestamp using iconv
- Removed "-Wno-deprecated"
- Added parallel make
- Kept timestamps on install command
- fixed %%defattr macro
- Added openssl-devel%{?_isa}
- Removed message on scriplet
- Changed from hash_map and hash_set headers to unordered_map
- Using glob instead multiples lines of install command
- Fixed documentation files
- Disabled silent mode in %%check section

* Tue Feb 22 2011 Sergio Belkin <sbelki@palermo.edu> 8.5.4-7
- Fixed License in order to match the actual license
- Clarified Base Package required
- Disabled static subpackage
- Removed .la libtool file instead of excluding
- %%check section added
- Minor change in %%description tags and Requires

* Thu Feb 18 2011 Sergio Belkin <sbelki@palermo.edu> 8.5.4-6
- Removed files creation on %%post section
- Removed glibc-devel as BuildRequires

* Thu Feb 17 2011 Sergio Belkin <sbelki@palermo.edu> 8.5.4-5
- Removed %%clean section
- Fixed a regression, there were incorrect paths in %%prep section

* Thu Feb 15 2011 Sergio Belkin <sbelki@palermo.edu> 8.5.4-4
- Fixed LDFLAGS problem
- Fixed release RPM

* Thu Feb 03 2011 Sergio Belkin <sbelki@palermo.edu> 8.5.4-3
- Polished install
- Added post-install action for devel subpackage
- README.FEDORA moved to devel package
- INSTALL file dropped as it is considered irrelevant
- Added symlink file to devel package and removed from non-devel package

* Mon Jan 31 2011 Sergio Belkin <sbelki@palermo.edu> 8.5.4-2
- Styles mixing fixed
- Added openssl-devel as BuildRequires
- Drop "." ant the end Summary
- Fixed BuildRoot
- Fixed Summary and Description
- Fixed %%pre and %%postun
- Fixed file-not-utf8
- Fixed spec file name

* Mon Jan 01 2011 Sergio Belkin <sbelki@palermo.edu> - 8.5.4-1
- first RPM made in Universidad de Palermo
